"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.output = void 0;
const zod_1 = require("zod");
function chunkLoadingType() {
    return zod_1.z
        .enum(["jsonp", "import-scripts", "require", "async-node", "import"])
        .or(zod_1.z.string());
}
function wasmLoadingType() {
    return zod_1.z.enum(["...", "fetch-streaming", "fetch", "async-node"]);
}
function libraryType() {
    return zod_1.z.enum([
        "...",
        "var",
        "module",
        "assign",
        "assign-properties",
        "this",
        "window",
        "self",
        "global",
        "commonjs",
        "commonjs2",
        "commonjs-module",
        "commonjs-static",
        "amd",
        "amd-require",
        "umd",
        "umd2",
        "jsonp",
        "system"
    ]);
}
function output() {
    return zod_1.z.strictObject({
        iife: zod_1.z.boolean().optional(),
        clean: zod_1.z.boolean().optional(),
        assetModuleFilename: zod_1.z.string().optional(),
        auxiliaryComment: zod_1.z
            .string()
            .or(zod_1.z.strictObject({
            amd: zod_1.z.string().optional(),
            commonjs: zod_1.z.string().optional(),
            commonjs2: zod_1.z.string().optional(),
            root: zod_1.z.string().optional()
        }))
            .optional(),
        chunkFormat: zod_1.z
            .enum(["array-push", "commonjs", "module"])
            .or(zod_1.z.literal(false))
            .optional(),
        chunkLoading: zod_1.z.literal(false).or(chunkLoadingType()).optional(),
        enabledChunkLoadingTypes: chunkLoadingType().array().optional(),
        chunkFilename: zod_1.z.string().optional(),
        cssChunkFilename: zod_1.z.string().optional(),
        cssFilename: zod_1.z.string().optional(),
        hotUpdateChunkFilename: zod_1.z.string().optional(),
        hotUpdateMainFilename: zod_1.z.string().optional(),
        webassemblyModuleFilename: zod_1.z.string().optional(),
        hashSalt: zod_1.z.string().optional(),
        filename: zod_1.z.string().optional(),
        sourceMapFilename: zod_1.z.string().optional(),
        importFunctionName: zod_1.z.string().optional(),
        publicPath: zod_1.z.string().optional(),
        uniqueName: zod_1.z.string().optional(),
        path: zod_1.z.string().optional(),
        crossOriginLoading: zod_1.z
            .literal(false)
            .or(zod_1.z.enum(["anonymous", "use-credentials"]))
            .optional(),
        enabledWasmLoadingTypes: wasmLoadingType().array().optional(),
        wasmLoading: zod_1.z.literal(false).or(wasmLoadingType()).optional(),
        enabledLibraryTypes: libraryType().or(libraryType().array()).optional(),
        globalObject: zod_1.z.string().min(1).optional(),
        libraryExport: zod_1.z.string().min(1).or(zod_1.z.string().min(1).array()).optional(),
        libraryTarget: libraryType().optional(),
        hashFunction: zod_1.z.string().or(zod_1.z.function()).optional(),
        // TODO(hyf0)
        module: zod_1.z.any().optional(),
        strictModuleErrorHandling: zod_1.z.any().optional(),
        umdNamedDefine: zod_1.z.any().optional(),
        chunkLoadingGlobal: zod_1.z.any().optional(),
        trustedTypes: zod_1.z.any().optional(),
        hashDigest: zod_1.z.any().optional(),
        hashDigestLength: zod_1.z.any().optional(),
        library: zod_1.z.any().optional()
    });
}
exports.output = output;
//# sourceMappingURL=output.js.map